
# Slot: opposite of


x is the opposite of y if there exists some distance metric M, and there exists no z such as M(x,z) <= M(x,y) or M(y,z) <= M(y,x). (This description is from RO. Needs to be rephrased).

URI: [biolink:opposite_of](https://w3id.org/biolink/vocab/opposite_of)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **See also:** | | https://doi.org/10.1101/108977 |
|  | | https://github.com/biolink/biolink-model/issues/657 |
| **Exact Mappings:** | | RO:0002604 |

